@@ -238,7 +238,7 @@ class FileInput(Widget):
         multiple is False or a list of bytes otherwise.""")
 
     _rename: ClassVar[Mapping[str, str | None]] = {
-        'filename': None, 'name': None
+        'filename': None
     }
 
     _source_transforms: ClassVar[Mapping[str, str | None]] = {
@@ -504,9 +504,11 @@ class DatePicker(Widget):
     end = param.CalendarDate(default=None, doc="""
         Inclusive upper bound of the allowed date selection""")
 
-    disabled_dates = param.List(default=None, item_type=(date, str))
+    disabled_dates = param.List(default=None, item_type=(date, str), doc="""
+        Dates to make unavailable for selection; others will be available.""")
 
-    enabled_dates = param.List(default=None, item_type=(date, str))
+    enabled_dates = param.List(default=None, item_type=(date, str), doc="""
+        Dates to make available for selection; others will be unavailable.""")
 
     width = param.Integer(default=300, allow_None=True, doc="""
       Width of this component. If sizing_mode is set to stretch
@@ -573,9 +575,11 @@ class DateRangePicker(Widget):
     end = param.CalendarDate(default=None, doc="""
         Inclusive upper bound of the allowed date selection""")
 
-    disabled_dates = param.List(default=None, item_type=(date, str))
+    disabled_dates = param.List(default=None, item_type=(date, str), doc="""
+        Dates to make unavailable for selection; others will be available.""")
 
-    enabled_dates = param.List(default=None, item_type=(date, str))
+    enabled_dates = param.List(default=None, item_type=(date, str), doc="""
+        Dates to make available for selection; others will be unavailable.""")
 
     width = param.Integer(default=300, allow_None=True, doc="""
       Width of this component. If sizing_mode is set to stretch
@@ -764,7 +768,8 @@ class DatetimePicker(_DatetimePickerBase):
 
     value = param.Date(default=None)
 
-    mode = param.String('single', constant=True)
+    mode = param.String('single', constant=True, doc="""
+        The mode of the datetime picker, which is always 'single' for this widget.""")
 
     def _serialize_value(self, value):
         if isinstance(value, str) and value:
@@ -799,7 +804,8 @@ class DatetimeRangePicker(_DatetimePickerBase):
     value = param.DateRange(default=None, doc="""
         The current value""")
 
-    mode = param.String('range', constant=True)
+    mode = param.String('range', constant=True, doc="""
+        The mode of the datetime picker, which is always 'range' for this widget.""")
 
     def _serialize_value(self, value):
         if isinstance(value, str) and value:
@@ -987,6 +993,9 @@ class _SpinnerBase(_NumericInputBase):
         Defines the multiplication factor applied to step when the page up
         and page down keys are pressed.""")
 
+    placeholder = param.String(default='', doc="""
+        Placeholder when the value is empty.""")
+
     wheel_wait = param.Integer(default=100, doc="""
         Defines the debounce time in ms before updating `value_throttled` when
         the mouse wheel is used to change the input.""")
@@ -1158,7 +1167,8 @@ class LiteralInput(Widget):
     """)
 
     type = param.ClassSelector(default=None, class_=(type, tuple),
-                               is_instance=True)
+                               is_instance=True, doc="""
+        A Python literal type (e.g. list, dict, set, int, float, bool, str).""")
 
     value = param.Parameter(default=None)
 
@@ -1194,7 +1204,7 @@ class LiteralInput(Widget):
             if event:
                 self.value = event.old
             types = repr(self.type) if isinstance(self.type, tuple) else self.type.__name__
-            raise ValueError(f'LiteralInput expected {types} type but value {new} '
+            raise ValueError(f'{self.__class__.__name__} expected {types} type, but value \'{new}\' '
                              f'is of type {type(new).__name__}.')
 
     def _process_property_change(self, msg):
@@ -1541,7 +1551,7 @@ class Switch(_BooleanWidget):
     """
 
     _rename: ClassVar[Mapping[str, str | None]] = {
-        'name': None, 'value': 'active'
+        'value': 'active'
     }
 
     _widget_type: ClassVar[type[Model]] = _BkSwitch
